@@ -10,6 +10,7 @@ from . import gn_transform as _gn_transform
 def cova2neq(cova: _np.ndarray, variance_factor):
     """Function to convert COVA matrix to NEQ matrix as per Bernese ADDNEQ"""
     neqm = _np.linalg.inv(cova / variance_factor)
+    # TODO could move neq = neq_est - neq_apr # N_total - N_constr from get_neq to here
     # neqv = neqm @ (vec.EST.values - vec.APR.values)
     # return neqm, neqv
     return neqm
@@ -104,11 +105,22 @@ def prepare_neq(neq_m, vec_apr_neq, frame_of_day):
     vec_apr_neq = vec_apr_neq.copy()
     neq_vec = vec_apr_neq.NEQ.values
     xyz_mask = _np.isin(vec_apr_neq.TYPE.values, ["STAX", "STAY", "STAZ"])
+    _logging.info(f'{xyz_mask.shape[0]} parameters present')
+
+    soln_nums = vec_apr_neq.SOLN[xyz_mask].unique() # XYZ only
+    if soln_nums.shape[0] > 1: # more than one solution present e.g. CODE snx -> select central
+        mid_soln = soln_nums[soln_nums.shape[0]//2]
+        mid_soln_mask = vec_apr_neq.SOLN.values == mid_soln
+        _logging.info(f'selecting solution No {mid_soln}')
+        xyz_mask &= mid_soln_mask
+
     idx2elim = vec_apr_neq.index.values[~xyz_mask]
 
-    # neq_mat,neq_vec = neq, neq_vec
-    for i in range(idx2elim.shape[0]):  # need to be positive and sorted from bigger to smaller
-        neq_elim_dim(neq_mat, neq_vec, idx2elim[i])
+    n_elim = idx2elim.shape[0]
+    if n_elim > 0:
+        _logging.info(f'eliminating {n_elim} parameters')
+        for i in range(n_elim):  # need to be positive and sorted from bigger to smaller
+            neq_elim_dim(neq_mat, neq_vec, idx2elim[i])
 
     neq_mat_elim = neq_mat[xyz_mask, :][:, xyz_mask]
     neq_vec_elim = neq_vec[xyz_mask]
@@ -119,6 +131,7 @@ def prepare_neq(neq_m, vec_apr_neq, frame_of_day):
         [vec_apr_neq.CODE.values + "_" + vec_apr_neq.PT.values.astype(str), vec_apr_neq.TYPE]
     )
     aprioris.index = index_combo
+
     aprioris = aprioris.unstack(level=1)
     aprioris_missing_mask = aprioris.STAX.values == 0
     aprioris_vals_mask = ~aprioris_missing_mask
@@ -176,6 +189,16 @@ def get_uniind(vec_list):
 
 
 def addneq(snx_filelist, frame_of_day):
+    """
+    This is the main combination function - extracts normal equation matrix+vector or converts available COVA/CORR to normal eq. counterparts. Only STAX/Y/Z values are being combined, hence rest must be eliminated before combining. All the solution values are first aligned to the ITRF/IGS frame to get close a priori values as required.
+    Care is needed with MIT, mig* specifically, and SIO solution files as available matrices are frequently singular. Singular matrices require additional treatment before inversion which has not been implemented yet.
+    Usage examples:
+    1. daily combination. Note than frame_of_day here is of midday of the day being processed:
+        daily_comb_neq = addneq(snx_filelist=_glob.glob('/data/cddis/2160/[!sio][!mig]*0.snx.Z'),frame_of_day=frame_of_day)
+    2. Weekly combination with frame_of_day centered at week's center:
+        weekly_comb_neq = addneq(snx_filelist=_glob.glob('/data/cddis/2160/[!sio][!mig]*.snx.Z'),frame_of_day=frame_of_day)
+    
+    """
     buf_neq, buf_vec = [], []
     for file in snx_filelist:
         neq, vec = get_neq(file)
