@@ -15,7 +15,7 @@ def _valvar2diffstd(valvar1, valvar2, trace=True, std_coeff=1):
     """Auxiliary function to efficiently difference two dataframes,
     each of them consisting of value-variance pairs"""
     df = _pd.concat([valvar1, valvar2], axis=0, keys=["valvar1", "valvar2"]).unstack(0)  # fastest\
-    df_nd = df.values
+    df_nd = df.values.astype(float)
     diff = df_nd[:, 0] - df_nd[:, 1]
     nan_mask = ~_np.isnan(diff)
 
@@ -567,7 +567,7 @@ def diffblq(blq_a_path, blq_b_path, tol, log_lvl):
     blq_a, blq_b = _gn_io.blq.read_blq(blq_a_path), _gn_io.blq.read_blq(blq_b_path)
     status = 0
     diff = blq_a - blq_b
-    bad_blq_vals = _diff2msg(diff.abs().T, 1e-4, dt_as_gpsweek=None)
+    bad_blq_vals = _diff2msg(diff.abs().T, tol=tol, dt_as_gpsweek=None)
     if bad_blq_vals is not None:
         _logging.log(
             msg=f':diffutil found diff magnitudes above {tol:.1E} tolerance:\n{bad_blq_vals.to_string(justify="center")}\n',
