@@ -762,4 +762,6 @@ def get_vars_from_file(path):
     spec = spec_from_loader("tags", SourceFileLoader("tags", path))
     tags = module_from_spec(spec)
     spec.loader.exec_module(tags)
-    return tags
+
+    tags_dict = ({item:getattr(tags, item) for item in dir(tags) if not item.startswith("__")})
+    return tags_dict
