@@ -58,9 +58,7 @@ def get_frame_of_day(date_or_j2000, itrf_path_or_df, discon_path_or_df, psd_path
         & (discon_df.END > date_J2000)
     ]
 
-    comboindex = _pd.Index(
-        output.CODE.values + "_" + output.PT.values.astype(object) + output.SOLN.values.astype(object)
-    )
+    comboindex = _pd.Index(output.CODE.values + "_" + output.PT.values.astype(object) + output.SOLN.values)
 
     itrf_code_pt = _pd.Index(output.CODE.values + "_" + output.PT.values.astype(object), name=None).unique()
     soln_series = _pd.Series(index=itrf_code_pt, data="1")
@@ -144,10 +142,10 @@ def psd2frame(frame_of_day, psd_df):
 
     llh = _gn_transform.xyz2llh_heik(xyz_array=frame_of_day[["STAX", "STAY", "STAZ"]].loc[psd_enu.index].values)
     phi, lam = llh[:, 0], llh[:, 1]
-    rot = _gn_transform.llh2rot(phi=phi, lamb=lam)
+    rot = _gn_transform.llh2rot(phi=phi, lamb=lam, enu_to_ecef=True)
 
     psd_xyz = _pd.DataFrame(
-        data=_np.squeeze(psd_enu.values[:, _np.newaxis] @ rot, axis=1),
+        data=(rot @ psd_enu.values[:, :, None]).reshape((-1, 3)),
         index=psd_enu.index,
         columns=["STAX", "STAY", "STAZ"],
     )
