@@ -3,10 +3,10 @@ import re as _re
 import numpy as _np
 import pandas as _pd
 
-from .. import gn_io as _gn_io
 from .. import gn_datetime as _gn_datetime
+from .. import gn_io as _gn_io
 
-_RE_BLKS = _re.compile(rb"H\n((?:[ \-\d]+\n)+)", _re.MULTILINE)
+_RE_IONEX_BLK = _re.compile(rb"H\n((?:[ \-\d]+\n)+)", _re.MULTILINE)
 
 
 def gen_range(head, param_name):
@@ -14,9 +14,7 @@ def gen_range(head, param_name):
     head_lon = head.find(param_name)
     head_lon_lineb = head[: head.find(param_name)].rfind(b"\n") + 1
     lon1, lon2, dlon = head[head_lon_lineb:head_lon].split()
-    lon1 = float(lon1)
-    lon2 = float(lon2)
-    dlon = float(dlon)
+    lon1, lon2, dlon = float(lon1), float(lon2), float(dlon)
     return _np.arange(lon1, lon2 + (0.1 if dlon > 0 else -0.1), dlon)
 
 
@@ -38,14 +36,14 @@ def read_ionex(path_or_bytes):
     maps_heads = find_all(data, b"START", window=[9, 60])  # type + epoch info
     maps_heads_arr = _np.asarray(b"".join(maps_heads).split()).reshape(len(maps_heads), -1)
     # return maps_heads
-    datetime = strdatetime2datetime(maps_heads_arr[:, 2:], as_j2000=True)
+    datetime = _gn_datetime.strdatetime2datetime(maps_heads_arr[:, 2:], as_j2000=True)
     maps_type = maps_heads_arr[:, 0].astype(str)
 
     exp = get_param(head, b"EXPONENT")
 
     maps_arr = (
-        _np.asarray(b"".join(_RE_BLKS.findall(data)).replace(b"\n", b""))[_np.newaxis].view("S5").astype(int)
-        * 10 ** exp
+        _np.asarray(b"".join(_RE_IONEX_BLK.findall(data)).replace(b"\n", b""))[_np.newaxis].view("S5").astype(int)
+        * 10**exp
     )
 
     lon_arr = gen_range(head, b"LON1 ")
@@ -72,19 +70,3 @@ def find_all(data, pat, window):
         buf.append(data[find + window[0] : find + window[1]])
         find = data.find(pat, find + len(pat))
     return buf
-
-
-def strdatetime2datetime(dt_arr, as_j2000=True):
-    """ndarray of Y M D h m s to datetime64"""
-    datetime = (
-        dt_arr[:, 0].astype("datetime64[M]")
-        + (dt_arr[:, 1].astype("timedelta64[M]") - 1)
-        + (dt_arr[:, 2].astype("timedelta64[D]") - 1)
-        + (dt_arr[:, 3].astype("timedelta64[h]"))
-        + (dt_arr[:, 4].astype("timedelta64[m]"))
-        + (dt_arr[:, 5].astype("timedelta64[s]"))
-    )
-
-    if as_j2000:
-        return _gn_datetime.datetime2j2000(datetime)
-    return datetime
